ChunkTicketStorage

Struct ChunkTicketStorage 

pub(crate) struct ChunkTicketStorage {
    tickets: FxHashMap<ChunkPos, Vec<StoredChunkTicket>>,
    timed_generation: u64,
}
Owns one logical ticket for each canonical type identity and level.

Fields

tickets: FxHashMap<ChunkPos, Vec<StoredChunkTicket>>timed_generation: u64

Implementations

Source

impl ChunkTicketStorage

pub(crate) fn new() -> Self

pub(crate) fn from_persistent( persistent: PersistentChunkTickets, ) -> Result<Self, ChunkTicketStorageLoadError>

Restores registered ticket types from saved data.

pub(crate) fn add_ticket( &mut self, pos: ChunkPos, ticket: ChunkTicket, ) -> SourceProjectionChanges

Adds one canonical ticket or refreshes an existing matching type and level.

pub(crate) fn remove_ticket( &mut self, pos: ChunkPos, ticket: ChunkTicket, ) -> SourceProjectionChanges

Removes the canonical ticket matching ticket’s type identity and level.

pub(crate) fn load_source_level( &self, pos: ChunkPos, ) -> Option<ChunkTicketLevel>

Returns the strongest loading ticket at pos.

pub(crate) fn simulation_source_level( &self, pos: ChunkPos, ) -> Option<ChunkTicketLevel>

Returns the strongest simulation ticket supported by Steel’s tracker at pos.

pub(crate) fn load_source_update(&self, pos: ChunkPos) -> SourceLevelUpdate

pub(crate) fn simulation_source_update( &self, pos: ChunkPos, ) -> SourceLevelUpdate

pub(crate) fn initial_load_sources(&self) -> Vec<SourceLevelUpdate>

Enumerates the initial loading sources for propagation tracker seeding.

pub(crate) fn initial_simulation_sources(&self) -> Vec<SourceLevelUpdate>

Enumerates the initial simulation sources for propagation tracker seeding.

fn initial_sources( &self, source_update: fn(&Self, ChunkPos) -> SourceLevelUpdate, ) -> Vec<SourceLevelUpdate>

pub(crate) fn add_or_refresh_portal_ticket( &mut self, pos: ChunkPos, ) -> SourceProjectionChanges

Adds or refreshes Vanilla’s post-portal ticket.

pub(crate) fn add_or_refresh_ender_pearl_ticket( &mut self, pos: ChunkPos, ) -> SourceProjectionChanges

Adds or refreshes Vanilla’s in-flight ender pearl ticket.

pub(crate) fn timed_ticket_expirations(&self) -> Vec<TimedTicketExpiration>

Snapshots the exact timed entries eligible for this world-tick pass.

pub(crate) fn tick_timed_tickets( &mut self, expirations: &[TimedTicketExpiration], ) -> SourceProjectionChanges

Ages unchanged timed entries selected by the current world-tick pass.

pub(crate) fn to_persistent(&self) -> PersistentChunkTickets

Converts every active ticket whose type has Vanilla’s persist flag.

fn add_loaded_persistent_ticket( &mut self, persistent: PersistentChunkTicket, ) -> Result<(), ChunkTicketStorageLoadError>

fn add_loaded_ticket(&mut self, pos: ChunkPos, ticket: ChunkTicket)

fn generation_for(&mut self, ticket_type: TicketTypeRef) -> Option<u64>

fn allocate_timed_generation(&mut self) -> u64

fn compare_expirations( left: &TimedTicketExpiration, right: &TimedTicketExpiration, ) -> Ordering

fn compare_persistent_tickets( left: &PersistentChunkTicket, right: &PersistentChunkTicket, ) -> Ordering