pub(crate) struct SourceProjectionChanges {
pub(crate) load_positions: Vec<ChunkPos>,
pub(crate) simulation_positions: Vec<ChunkPos>,
}Expand description
Source positions dirtied by one or more storage mutations.
Positions are present only when canonical source membership changed and may repeat when several mutations are merged.
Fields
load_positions: Vec<ChunkPos>simulation_positions: Vec<ChunkPos>Implementations
Sourceimpl SourceProjectionChanges
impl SourceProjectionChanges
fn for_ticket(pos: ChunkPos, ticket: ChunkTicket) -> Self
pub(crate) fn merge(&mut self, other: Self)